Manyworlds
==========

.. toctree::
   :maxdepth: 5
   :caption: Contents:

manyworlds.feature module
----------------------------------

.. automodule:: manyworlds.feature
   :members:
   :undoc-members:
   :show-inheritance:

manyworlds.scenario module
--------------------------

.. automodule:: manyworlds.scenario
   :members:
   :undoc-members:
   :show-inheritance:

manyworlds.step module
----------------------

.. automodule:: manyworlds.step
   :members:
   :undoc-members:
   :show-inheritance:

manyworlds.data\_table module
-----------------------------

.. automodule:: manyworlds.data_table
   :members:
   :undoc-members:
   :show-inheritance:
